"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const usehooks_ts_1 = require("usehooks-ts");
const useAsyncHandler_1 = __importDefault(require("./useAsyncHandler"));
function useAsyncFetch(onActionFn, options) {
    const { maxTries = 1, timeoutBeforeRetry = 1000 } = options || {};
    const [tries, setTries] = (0, react_1.useState)(0);
    const action = (0, useAsyncHandler_1.default)(onActionFn, { strict: true });
    const { isLoading, isDone, error, data, reset } = action;
    function handleTry() {
        if (isDone || isLoading)
            return;
        if (tries >= maxTries)
            return;
        setTries(tries + 1);
        action.execute();
    }
    (0, react_1.useEffect)(() => {
        handleTry();
    }, []);
    const isTimeoutEnabled = tries && tries < maxTries && !isLoading && !isDone;
    (0, usehooks_ts_1.useTimeout)(handleTry, isTimeoutEnabled ? timeoutBeforeRetry : null);
    return { isLoading, isDone, error, data, reset, tries };
}
exports.default = useAsyncFetch;
//# sourceMappingURL=useAsyncFetch.js.map